pub struct MinesweeperClient { /* private fields */ }Expand description
HTTP client for minesweeper server API
Implementations
Sourceimpl MinesweeperClient
impl MinesweeperClient
Sourcepub fn new(base_url: &str) -> Result<Self>
pub fn new(base_url: &str) -> Result<Self>
Create a new client connecting to the specified server URL
Sourcepub async fn create_game(&self, params: GameParams) -> Result<String>
pub async fn create_game(&self, params: GameParams) -> Result<String>
Create a new game with the specified parameters Returns the game ID that can be used to connect via WebSocket
Sourcepub fn websocket_url(&self, game_id: &str) -> Result<String>
pub fn websocket_url(&self, game_id: &str) -> Result<String>
Get the WebSocket URL for a game